<?php
/**
 * Enqueue scripts and styles
 *
 * @package softgen
 */

/**
 * Google Font Function
 *
 * @return void
 */
function softgen_google_fonts_url() {

    $fonts_url = '';
    if( 'yes' === softgen_get_option( 'global_font_control', 'no' ) ) {
        $prmary_font = softgen_get_option('primary_font');
        $base_font = softgen_get_option('base_font');
        $Syne = ! empty( $prmary_font['font-family'] ) ? 'off' : 'on';
        $DmSans = ! empty( $base_font['font-family'] ) ? 'off' : 'on';
    }else{
        $Syne = 'on';
        $DmSans = 'on';
    }

    if ( 'off' !== $Syne || 'off' !== $DmSans ) {
        $font_families = array();

        if ( 'off' !== $Syne ) {
            $font_families[] = 'Syne:400,500,600,700';
        }

        if ( 'off' !== $DmSans ) {
            $font_families[] = 'DM Sans:400,500,600';
        }

        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );

        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }

    return esc_url_raw( $fonts_url );
}

/**
 * Get filemtime
 *
 * @param [type] $path
 * @return void
 */
function softgen_get_filemtime( $path ) {
    if ( ! empty( $path ) ) {
        return filemtime( get_template_directory() . '/assets/' . $path );
    } else {
        return _SOFTGEN_VERSION;
    }
}

function softgen_get_styles() {
    $min = ( WP_DEBUG === true ) ? '' : '.min';
    return [
        'softgen-google-fonts'    => [
            'src'     => softgen_google_fonts_url(),
            'version' => null,
        ],
        'softgen-dl-icons'        => [
            'src'     => get_template_directory_uri() . '/assets/css/dl-icons.min.css',
            'version' => '1.0',
        ],
        'elementor-icons-line-awesome-icons'        => [
            'src'     => get_template_directory_uri() . '/assets/lib/line-awesome/line-awesome.min.css',
            'version' => '1.0',
        ],
        'owl-carousel'            => [
            'src'     => get_template_directory_uri() . '/assets/lib/owl-carousel/assets/owl.carousel.min.css',
            'version' => '2.3.4',
        ],
        'justified-gallery-css'            => [
            'src'     => get_template_directory_uri() . '/assets/lib/justifiedGallery/justifiedGallery.min.css',
            'version' => '3.8.0',
        ],
        'softgen-jquary-ui'       => [
            'src'     => get_template_directory_uri() . '/assets/css/jquary-ui.min.css',
            'version' => '1.13.1',
        ],
        'softgen-common-style'    => [
            'src'     => get_template_directory_uri() . '/assets/css/common-style' . $min . '.css',
            'version' => softgen_get_filemtime( 'css/common-style' . $min . '.css' ),
        ],
        'softgen-main-style'      => [
            'src'     => get_template_directory_uri() . '/assets/css/main' . $min . '.css',
            'version' => softgen_get_filemtime( 'css/main' . $min . '.css' ),
        ],
        'softgen-shop-common'     => [
            'src'     => get_template_directory_uri() . '/assets/css/woo/shop-common' . $min . '.css',
            'version' => softgen_get_filemtime( 'css/woo/shop-common' . $min . '.css' ),
        ],
        'softgen-shop'            => [
            'src'     => get_template_directory_uri() . '/assets/css/woo/shop' . $min . '.css',
            'deps'    => ['wc-blocks-style-cart'],
            'version' => softgen_get_filemtime( 'css/woo/shop' . $min . '.css' ),
        ],
        'softgen-checkout'        => [
            'src'     => get_template_directory_uri() . '/assets/css/woo/checkout' . $min . '.css',
            'deps'    => ['wc-blocks-packages-style'],
            'version' => softgen_get_filemtime( 'css/woo/checkout' . $min . '.css' ),
        ],
        'softgen-shop-my-account' => [
            'src'     => get_template_directory_uri() . '/assets/css/woo/my-account' . $min . '.css',
            'version' => softgen_get_filemtime( 'css/woo/my-account' . $min . '.css' ),
        ],

    ];
}

function softgen_get_scripts() {
    $min = ( WP_DEBUG === true ) ? '' : '.min';
    return [
        'owl-carousel'  => [
            'src'     => get_template_directory_uri() . '/assets/lib/owl-carousel/owl.carousel.min.js',
            'version' => '2.3.4',
            'footer'  => true,
        ],
        'sharer'  => [
            'src'     => get_template_directory_uri() . '/assets/lib/sharer/sharer.min.js',
            'version' => '0.5.1',
            'footer'  => true,
        ],
        'justified-gallery-js'  => [
            'src'     => get_template_directory_uri() . '/assets/lib/justifiedGallery/jquery.justifiedGallery.min.js',
            'version' => '3.8.0',
            'footer'  => true,
        ],
        'softgen-main' => [
            'src'     => get_template_directory_uri() . '/assets/js/main' . $min . '.js',
            'version' => softgen_get_filemtime( 'js/main' . $min . '.js' ),
            'footer'  => true,
        ],
    ];
}

/**
 * Assets
 *
 * @return void
 */
function softgen_assets() {
    
    $styles  = softgen_get_styles();
    $scripts = softgen_get_scripts();
    foreach ( $styles as $handle => $style ) {
        $deps = isset( $style['deps'] ) ? $style['deps'] : false;
        wp_register_style( $handle, $style['src'], $deps, $style['version'] );
    }
    foreach ( $scripts as $script_handle => $script ) {
        $script_deps = isset( $script['deps'] ) ? $script['deps'] : false;
        wp_register_script( $script_handle, $script['src'], $script_deps, $script['version'], $script['footer'] );
    }

    wp_enqueue_style( 'softgen-google-fonts' );
    wp_enqueue_style( 'softgen-dl-icons' );
    wp_enqueue_style( 'elementor-icons-line-awesome-icons' );
    wp_enqueue_style( 'softgen-jquary-ui' );
    wp_enqueue_style( 'softgen-common-style' );
    wp_enqueue_style( 'softgen-main-style' );

    if ( class_exists( 'WooCommerce' ) ) {

        wp_enqueue_style( 'softgen-shop-common' );

        if ( is_shop() || is_tax( 'product_cat' ) || is_singular( 'product' ) || is_tax( 'product_tag' ) || is_cart() ) {
            wp_enqueue_style( 'softgen-shop' );
        }

        if ( is_checkout() ) {
            wp_enqueue_style( 'softgen-checkout' );
        }

        if ( is_account_page() ) {
            wp_enqueue_style( 'softgen-shop-my-account' );
        }
    }

    wp_enqueue_style( 'softgen-style', get_stylesheet_uri(), array(), _SOFTGEN_VERSION );
    
    if( is_rtl() ) {
        wp_enqueue_style( 'softgen-rtl-style', get_template_directory_uri() . '/rtl.css', array('softgen-style'), _SOFTGEN_VERSION );
    }

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    if ( is_singular( 'dl-project' ) ) {
        if( 'show' === softgen_get_option( 'project_social_share', 'show' ) ) {
            wp_enqueue_script('sharer');
        }
        if( 'show' === softgen_get_option( 'related_project', 'show' ) ) {
            wp_enqueue_style('owl-carousel');
            wp_enqueue_script('owl-carousel');
        }
    }

    if( is_singular( 'post' ) ) {
        if( 'show' === softgen_get_option( 'blog_post_share', 'show' ) ) {
            wp_enqueue_script('sharer');
        }
    }

    if( is_page() ) {
        if( 'show' === softgen_get_option( 'page_social_share', 'show' ) ) {
            wp_enqueue_script('sharer');
        }
    }

    wp_enqueue_script( 'jquery-ui-selectmenu' );
    wp_enqueue_script( 'masonry' );
    wp_enqueue_script( 'softgen-main' );

    $sticky_header = softgen_get_option( 'header_sticky', 'enable' );
    $scrollto_top = softgen_get_option( 'gototop_btn', 'enable' );
    $custom_cursor = softgen_get_option( 'custom_cursor', 'show' );
    $preloader = 'disable' != softgen_get_option( 'preloader_control', 'show_all' ) ? 'enable' : 'disable';
    wp_localize_script( 'softgen-main', 'softgen_data', [
        'sticky'      => $sticky_header,
        'scrollto_top' => $scrollto_top,
        'preloader' => $preloader,
        'custom_cursor' => $custom_cursor
    ] );

}
add_action( 'wp_enqueue_scripts', 'softgen_assets' );

/**
 * Custom CSS Variables
 */
function softgen_css_custom_variables() {
    echo '<style>:root {
        --softgen-primary-font: "Syne", sans-serif;
        --softgen-secondary-font: "DM Sans", sans-serif;
        --softgen-primary-color: #4b83ff;
        --softgen-secondary-color: #089fac;
        --softgen-white-color: #fff;
        --softgen-dark-color: #191d28;
        --softgen-grey-color: #5d6374;
        --softgen-grey-light-color: #b8b8b8;
        --softgen-bg-white: #fff;
        --softgen-bg-dark: #110718;
        --softgen-bg-dark-light: #212140;
        --softgen-bg-light-color: #F3F7FE;
        --softgen-border-color: #11071820;
        --softgen-bg-primary-transparent: rgba(255, 106, 50, 0.7);
        --softgen-bg-secondary-transparent: rgba(8, 159, 172, 0.6);
        --softgen-bg-gradiant-color: linear-gradient(45deg, rgba(255, 106, 50, 1) 0%, rgba(8, 159, 172, 1) 100%);
        --softgen-bg-gradiant-transparent: linear-gradient(45deg, rgba(255, 106, 50, 0.9) 0%, rgba(8, 159, 172, 0.9) 100%);
        --softgen-shadow-sm: 0px 8px 16px 0px rgba(0, 0, 0, 0.04);
        --softgen-shadow-lg: 0px 8px 18px 0px rgba(0, 0, 0, 0.1);
    }</style>';
}

if( ! class_exists('softgenCore') ) {
    add_action( 'wp_head','softgen_css_custom_variables', 5);
}