<?php
/**
 * Custom CSS
 *
 * @package softgen
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class SoftgenCustomCSS {

    /**
     * Constructor Function
     */
    public function __construct() {
        add_action( 'wp_head', [$this, 'custom_css_variables'], 5 );
        add_action( 'wp_enqueue_scripts', [$this, 'custom_style'] );
        add_action( 'login_enqueue_scripts', [$this, 'login_page_style'] );
    }

    /**
     * Custom CSS Variables
     */
    public function custom_css_variables() {
        $cssvariables = '';
        $cssvariables .= ':root {';
        $cssvariables .= $this->css_global_variables();
        $cssvariables .= '--softgen-white-color: #fff; --softgen-bg-white: #fff; --softgen-bg-light-color: #F3F7FE; --softgen-border-color: #11071820; --softgen-shadow-sm: 0px 8px 16px 0px rgba(0, 0, 0, 0.04); --softgen-shadow-lg: 0px 30px 60px 0px rgba(10.000000000000004, 42.999999999999964, 82.99999999999999, 0.14901960784313725);';
        $cssvariables .= '}';
        echo "<style>{$cssvariables}</style>";
    }

    /**
     * Add inline style helper
     *
     * @param [type] $handle
     * @param [type] $data
     * @return void
     */
    public function add_inline_style( $handle, $data ) {
        _wp_scripts_maybe_doing_it_wrong( __FUNCTION__, $handle );

        if ( false !== stripos( $data, '</style>' ) ) {
            _doing_it_wrong(
                __FUNCTION__,
                sprintf(
                    __( 'Do not pass %1$s tags to %2$s.', 'softgen' ),
                    '<code>&lt;style&gt;</code>',
                    '<code>wp_add_inline_style()</code>'
                ),
                '3.7.0'
            );
            $data = trim( preg_replace( '#<style[^>]*>(.*)</style>#is', '$1', $data ) );
        }

        return wp_styles()->add_inline_style( $handle, $data );
    }

    /**
     * Login page style
     *
     * @return void
     */
    public function login_page_style() {
        $data = '';
        $body_bg = get_template_directory_uri() . '/assets/img/body-bg.jpg';
        $login_logo      = ! empty( softgen_get_option( 'login_logo' )['url'] ) ? softgen_get_option( 'login_logo' )['url'] : get_template_directory_uri() . '/assets/img/logo.png';
        $login_logo_size = softgen_get_option( 'login_logo_size', 100 );
        $dimensions      = softgen_get_option( 'login_logo_dimensions' );
        $logo_width      = ! empty( $dimensions['width'] ) ? 'width:' . $dimensions['width'] . 'px!important;' : '';
        $logo_height     = ! empty( $dimensions['height'] ) ? 'height:' . $dimensions['height'] . 'px!important;' : '';
        $overlay         = softgen_get_option( 'login_overlay' );

        $data .= '.login h1 a{ width: 200px!important; margin: 0 auto 10px!important; }';
        if ( $login_logo != '' ) {
            $data .= '.login h1 a{ background-image:url(' . esc_url( $login_logo ) . ') !important;' . esc_html( $logo_height ) . esc_html( $logo_width ) . 'background-size: ' . esc_html( $login_logo_size ) . '% !important; background-position: center center!important; }';
        }

        $data .= 'body.login {  background-color: #F3F7FE; background-size: auto; background-position: left top; background-repeat: repeat; background-attachment: scroll; position: relative; z-index: 1; background-image: url('. esc_attr( $body_bg ) .'); }';
        $data .= SoftgenCsfHelper::background( 'body.login', softgen_get_option( 'login_bg' ) );

        if ( 'show' === $overlay ) {
            $data .= 'body.login:before { content: ""; width: 100%; height: 100%; position: absolute; left: 0; top: 0; z-index: -1; ' . SoftgenCsfHelper::slider( 'opacity', softgen_get_option( 'login_overlay_opacity' ), '' ) . ' }';
            $data .= SoftgenCsfHelper::background( 'body.login:before', softgen_get_option( 'login_overlay_bg' ) );
        }

        if ( $data ) {
            echo '<style type="text/css">' . SoftgenHelper::kses_basic( $data ) . '</style>';
        }
    }

    /**
     * Custom Style
     *
     * @return void
     */
    public function custom_style() {
        $classes = get_body_class();
        $data    = '';
        
        if ( ! in_array( 'no-page-banner', $classes ) ) {
            $data .= $this->page_banner();
        }
        $data .= $this->error_page_style();
        $data .= $this->font_styles();
        $data .= $this->blog_post_block_style();
        $data .= $this->pagination_styles();
        $data .= $this->srolltotop_styles();

        if( 'show_all' === softgen_get_option('preloader_control', 'show_all') ) {
            $data .= $this->preloader_styles();
        } elseif( 'only_home' === softgen_get_option('preloader_control', 'show_all') ) {
            if( is_home() ) {
                $data .= $this->preloader_styles();
            }
        }

        if ( 'default' === softgen_get_option( 'softgen_footer_template', 'default' ) ) {
            $data .= $this->footer_styles();
        }
        $data .= $this->desktop_css();
        $data .= $this->tablet_css();
        $data .= $this->mobile_css();
        
        $this->add_inline_style( 'softgen-style', $data );
    }

    /**
     * CSS Global Variables
     *
     * @return string
     */
    public function css_global_variables() {
        $data = '';
        
        if( 'yes' === softgen_get_option('primary_color_style', 'no' ) ) {
            // Colors
            $base_color = softgen_get_option('global_base_color');
            $primary_color = softgen_get_option('primary_color');
            $secondary_color = softgen_get_option('secondary_color');
            $heading_color = softgen_get_option('global_heading_color');
            $light_grey_color = softgen_get_option('global_light_grey_color');

            $data .= ! empty( $base_color ) ? "--softgen-grey-color: {$base_color};" : "--softgen-grey-color: #5d6374;";
            $data .= ! empty( $primary_color ) ? "--softgen-primary-color: {$primary_color};" : "--softgen-primary-color: #4b83ff;";
            $data .= ! empty( $secondary_color ) ? "--softgen-secondary-color: {$secondary_color};" : "--softgen-secondary-color: #089fac;";
            $data .= ! empty( $dark_color ) ? "--softgen-dark: {$dark_color};" : "--softgen-dark: #110718;";
            $data .= ! empty( $heading_color ) ? "--softgen-dark-color: {$heading_color};" : "--softgen-dark-color: #191d28;";
            $data .= ! empty( $light_grey_color ) ? "--softgen-grey-light-color: {$light_grey_color};" : "--softgen-grey-light-color: #b8b8b8;";
            
            // Background Colors
            $primary_bg_color = softgen_get_option('global_primary_bg_color');
            $secondary_bg_color = softgen_get_option('global_secondary_bg_color');
            $dark_bg_color = softgen_get_option('global_dark_bg_color');
            $dark_light_bg_color = softgen_get_option('global_dark_light_bg_color');

            $data .= ! empty( $primary_bg_color ) ? "--softgen-bg-primary-transparent: {$primary_bg_color};" : "--softgen-bg-primary-transparent: rgba(255, 106, 50, 0.7);";
            $data .= ! empty( $secondary_bg_color ) ? "--softgen-bg-secondary-transparent: {$secondary_bg_color};" : "--softgen-bg-secondary-transparent: rgba(8, 159, 172, 0.6);";
            $data .= ! empty( $dark_bg_color ) ? "--softgen-bg-dark: {$dark_bg_color};" : "--softgen-bg-dark: #110718;";
            $data .= ! empty( $dark_light_bg_color ) ? "--softgen-bg-dark-light: {$dark_light_bg_color};" : "--softgen-bg-dark-light: #212140;";

            // Gradient Colors
            $custom_gradient_color = softgen_get_option('custom_gradient_color', 'no');
            if( 'yes' === $custom_gradient_color ) {
                $gradient_solid_color = SoftgenCsfHelper::getGradient( softgen_get_option('gradient_solid_color') );
                $gradient_transparent_color = SoftgenCsfHelper::getGradient( softgen_get_option('gradient_transparent_color') );
                
                $data .= ! empty( $gradient_solid_color ) ? '--softgen-bg-gradiant-color: ' . $gradient_solid_color . ';' : '--softgen-bg-gradiant-color: linear-gradient(45deg, rgba(101, 182, 255, 1) 0%, rgba(75, 131, 255, 1) 100%);';
                $data .= ! empty( $gradient_transparent_color ) ? '--softgen-bg-gradiant-transparent: ' . $gradient_transparent_color . ';' : '--softgen-bg-gradiant-transparent: linear-gradient(45deg, rgba(101, 182, 255, 0.9) 0%, rgba(75, 131, 255, 0.9) 100%);';
            }else{
                $data .= '--softgen-bg-gradiant-color: linear-gradient(45deg, rgba(101, 182, 255, 1) 0%, rgba(75, 131, 255, 1) 100%); --softgen-bg-gradiant-transparent: linear-gradient(45deg, rgba(101, 182, 255, 0.9) 0%, rgba(75, 131, 255, 0.9) 100%);';
            }
        }else{
            $data .= '--softgen-grey-color: #5d6374; --softgen-primary-color: #4b83ff; --softgen-secondary-color: #089fac; --softgen-dark: #110718; --softgen-dark-color: #191d28; --softgen-grey-light-color: #b8b8b8; --softgen-bg-primary-transparent: rgba(255, 106, 50, 0.7); --softgen-bg-secondary-transparent: rgba(8, 159, 172, 0.6); --softgen-bg-dark: #110718; --softgen-bg-dark-light: #212140; --softgen-bg-gradiant-color: linear-gradient(45deg, rgba(101, 182, 255, 1) 0%, rgba(75, 131, 255, 1) 100%); --softgen-bg-gradiant-transparent: linear-gradient(45deg, rgba(101, 182, 255, 0.9) 0%, rgba(75, 131, 255, 0.9) 100%);';
        }

        if( 'yes' === softgen_get_option( 'global_font_control', 'no' ) ) {
            $prmary_font = softgen_get_option('primary_font');
            $base_font = softgen_get_option('base_font');
            if( ! empty( $base_font['font-family'] ) ) {
                $data .= '--softgen-secondary-font: "'. $base_font['font-family'] .'", sans-serif;';
            }else{
                $data .= '--softgen-secondary-font: "DM Sans", sans-serif;';
            }
            if( ! empty( $prmary_font['font-family'] ) ) {
                $data .= '--softgen-primary-font: "'. $prmary_font['font-family'] .'", sans-serif;';
            }else{
                $data .= '--softgen-primary-font: "Syne", sans-serif;';
            }
        }else{
            $data .= '--softgen-secondary-font: "DM Sans", sans-serif; --softgen-primary-font: "Syne", sans-serif;';
        }
        
        return $data;
    }

    /**
     * Page Header Custom Style
     *
     * @return string
     */
    public function page_banner() {
        $data = '';
        $global_gradient_bg = softgen_get_option( 'ph_gradient_bg', 'gradient-bg-1' );
        $project_gradient_bg = softgen_get_option( 'project_ph_gradient_bg', 'gradient-bg-1' );
        
        if( 'custom' != $global_gradient_bg ) {
            $data .= self::output_single( '.page-banner,.post-banner', 'background-image: url('. get_template_directory_uri() .'/assets/img/gradient/'. $global_gradient_bg .'.jpg)' );
        }else{
            $data .= SoftgenCsfHelper::background( '.page-banner', softgen_get_option( 'global_page_bg' ) );
        }
        
        if ( is_home() ) {
            $data .= SoftgenCsfHelper::background( '.blog .page-banner', softgen_get_option( 'blog_page_banner_bg' ) );
        }

        if ( is_archive() && ! is_author() ) {
            $data .= SoftgenCsfHelper::background( '.archive .page-banner', softgen_get_option( 'ph_archive_page_bg' ) );
        }
        if ( is_search() ) {
            $data .= SoftgenCsfHelper::background( '.search .page-banner', softgen_get_option( 'ph_search_page_bg' ) );
        }
        if ( is_author() ) {
            $data .= SoftgenCsfHelper::background( '.archive.author .page-banner', softgen_get_option( 'ph_author_page_bg' ) );
        }
        if( is_singular('dl-service') ) {
            $data .= SoftgenCsfHelper::background( '.service-header-area', softgen_get_option( 'service_page_banner_bg' ) );
            $data .= SoftgenCsfHelper::background( '.service-header-area:before', softgen_get_option( 'service_single_overlay_color' ) );
        }
        if( is_post_type_archive('dl-project') || is_tax('project-category') ) {
            
            
            $data .= SoftgenCsfHelper::background( '.post-type-archive-dl-project .page-banner, .archive.tax-project-category .page-banner', softgen_get_option( 'project_a_page_banner_bg' ) );
            $data .= SoftgenCsfHelper::background( '.post-type-archive-dl-project .page-banner .overlay, .archive.tax-project-category .page-banner .overlay', softgen_get_option( 'project_a_overlay_color' ) );
        }
        if ( 'yes' === softgen_get_option( 'ph_custom_style', 'no' ) ) {
            $custom_styles = softgen_get_option( 'ph_custom_style_tab' );
            if ( is_page() || is_home() ) {
                $subtitle_shape_color = $this->array_key_exists( 'ph_subtitle_shape_color', $custom_styles );
                $subtitle_color = SoftgenCsfHelper::getGradient( $this->array_key_exists( 'ph_subtitle_color', $custom_styles ) );
                if( ! empty( $subtitle_color ) ) {
                    $sutitle_css_var = '--softgen-subtitle-color: ' . $subtitle_color;
                    $data .= self::output_single('.page-banner-info h4', $sutitle_css_var );
                }
                if( ! empty( $subtitle_shape_color ) ) {
                    $sutitle_shape_var = '--softgen-secondary-color: ' . $subtitle_shape_color;
                    $data .= self::output_single('.page-banner-info h4', $sutitle_shape_var );
                }
                $data .= SoftgenCsfHelper::typography( '.page-banner-info h4', $this->array_key_exists( 'ph_subtitle_typography', $custom_styles ) );
            }
            $title_hl_color = SoftgenCsfHelper::getGradient( $this->array_key_exists( 'ph_title_hl_color', $custom_styles ) );
            $data .= SoftgenCsfHelper::typography( '.post-banner .post-banner-inner h1, .page-banner-info h1', $this->array_key_exists( 'ph_title_typography', $custom_styles ) );
            if( ! empty( $title_hl_color ) ) {
                $title_hl_color_var = $sutitle_css_var = '--softgen-title-hl-color: ' . $title_hl_color;
                $data .= self::output_single('.post-banner .post-banner-inner h1 span, .page-banner-info h1 span', $title_hl_color_var );
            }
            $data .= SoftgenCsfHelper::typography( '.post-banner-inner p, .page-banner-info p', $this->array_key_exists( 'ph_desc_typography', $custom_styles ) );
        }
        if ( 'show' === softgen_get_option( 'ph_breadcrumbs', 'show' ) && 'yes' === softgen_get_option( 'breadcrumbs_custom_style', 'no' ) ) {
            if ( ! empty( softgen_get_option('ph_breadcrumbs_sep') ) ) {
                $data .= '.breadcrumb-wrap li span.sep{' . SoftgenCsfHelper::color( 'background', softgen_get_option('ph_breadcrumbs_sep') ) . '}';
            }
            $data .= SoftgenCsfHelper::typography( '.breadcrumb-wrap li', softgen_get_option('ph_breadcrumbs_typography') );
            if ( ! empty( softgen_get_option('ph_breadcrumbs_active') ) ) {
                $data .= '.breadcrumb-wrap li.active{' . SoftgenCsfHelper::color( 'color', softgen_get_option('ph_breadcrumbs_active') ) . '}';
            }
        }
        if( is_singular('dl-project') ) {
            if( 'custom' === softgen_get_option( 'project_bg_img', 'featured' ) ) {
                if( 'custom' != $project_gradient_bg ) {
                    $data .= self::output_single( '.single-dl-project .page-banner', 'background-image: url('. get_template_directory_uri() .'/assets/img/gradient/'. $project_gradient_bg .'.jpg)' );
                }else{
                    $data .= SoftgenCsfHelper::background( '.single-dl-project .page-banner', softgen_get_option( 'project_ph_bg' ) );
                }
            }else{
                $data .= SoftgenCsfHelper::background( '.single-dl-project .page-banner:before', softgen_get_option('project_overlay_color') );
            }
        }
        if( is_singular('dl-service') ) {
            if( 'custom' === softgen_get_option( 'service_bg_img', 'featured' ) ) {
                $data .= SoftgenCsfHelper::background( '.single-dl-service .service-header-area', softgen_get_option('service_page_banner_bg') );
            }
            $data .= SoftgenCsfHelper::background( '.single-dl-service .service-header-area:before', softgen_get_option('service_overlay_color') );
        }
        if( class_exists('WooCommerce') ) {
            $data .= SoftgenCsfHelper::background( '.woocommerce-shop .page-banner.shop-ph-header', softgen_get_option('woo_php_bg') );
        }

        return $data;
    }

    /**
     * Page Banner Overlay Style
     *
     * @return void
     */
    public function page_banner_overlay() {
        $overlay = softgen_get_option( 'ph_overlay', 'disable' );
        $data    = '';
        if ( 'enable' === $overlay ) {
            $data .= SoftgenCsfHelper::background( '.page-banner:not(.no-image) .overlay', softgen_get_option( 'ph_overlay_color' ) );
            $data .= '.page-banner:not(.no-image) .overlay{' . SoftgenCsfHelper::slider( 'opacity', softgen_get_option( 'ph_overlay_opacity' ), '' ) . '}';
        }
        return $data;
    }

    /**
     * Error Page Style
     *
     * @return void
     */
    public function error_page_style(){
        $data = '';
        $gradient_bg = softgen_get_option( 'error_gradient_bg', 'gradient-bg-1' );
        
        if( 'custom' != $gradient_bg ) {
            $data .= self::output_single( '.error-page-wrap', 'background-image: url('. get_template_directory_uri() .'/assets/img/gradient/'. $gradient_bg .'.jpg)' );
        }else{
            $data .= SoftgenCsfHelper::background( '.error-page-wrap', softgen_get_option( 'error_custom_page_bg' ) );
        }
        return $data;
    }

    /**
     * Blog Post Style
     *
     * @return string
     */
    public function blog_post_block_style() {
        $custom_style = softgen_get_option( 'blog_post_custom_style', 'no' );
        $data         = '';
        if ( 'yes' === $custom_style ) {
            $styles_data = softgen_get_option( 'blog_post_custom_styles' );
            $data .= $this->output_single( '.post-items.classic .article-inner, .post-items.grid .article-inner', SoftgenCsfHelper::color( 'background-color', $this->array_key_exists( 'blog_card_bg_color', $styles_data ) ) );
            if ( 'show' === softgen_get_option( 'blog_post_cat', 'show' ) ) {
                $data .= SoftgenCsfHelper::background( '.post-items article .dl-cat-items .dl-cat-item', $this->array_key_exists( 'cat_bg', $styles_data ) );
                $data .= SoftgenCsfHelper::typography( '.post-items article .dl-cat-items .dl-cat-item', $this->array_key_exists( 'cat_typo', $styles_data ) );
                $data .= SoftgenCsfHelper::background( '.post-items article .dl-cat-items .dl-cat-item:hover', $this->array_key_exists( 'cat_bg_hover', $styles_data ) );
                $data .= $this->output_single( '.post-items article .dl-cat-items .dl-cat-item:hover', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'cat_hover_color', $styles_data ) ) );
            }
            $data .= SoftgenCsfHelper::typography( '.post-items article .post-content .post-meta a', $this->array_key_exists( 'meta_typo', $styles_data ) );
            $data .= $this->output_single( '.post-items article .post-content .post-meta a i', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'meta_icon_color', $styles_data ) ) );
            $data .= $this->output_single( '.post-items article .post-content .post-meta a:hover', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'meta_hover_color', $styles_data ) ) );
            $data .= SoftgenCsfHelper::typography( '.post-items article.post .entry-title', $this->array_key_exists( 'heading_typo', $styles_data ) );
            $data .= SoftgenCsfHelper::typography( '.post-items article .entry-title a', $this->array_key_exists( 'heading_typo', $styles_data ), 'color' );
            $data .= $this->output_single( '.post-items article .entry-title a', SoftgenCsfHelper::color( '--softgen-primary-color', $this->array_key_exists( 'heading_hover_color', $styles_data ) ) );
            $data .= $this->output_single( '.post-items article .entry-title a:hover', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'heading_hover_color', $styles_data ) ) );
            if ( 'show' === softgen_get_option( 'blog_post_excerpt' ) ) {
                $data .= SoftgenCsfHelper::typography( '.post-items article.post .entry-content', $this->array_key_exists( 'excerpt_typo', $styles_data ) );
            }
            if ( 'show' === softgen_get_option( 'blog_post_readmore' ) ) {
                $data .= SoftgenCsfHelper::typography( '.post-items article.post .entry-footer .readmore', $this->array_key_exists( 'readmore_typo', $styles_data ) );
                $data .= $this->output_single( '.post-items article.post .entry-footer .readmore:hover', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'readmore_hover_color', $styles_data ) ) );
            }
            if ( 'show' === softgen_get_option( 'blog_post_comment' ) ) {
                $data .= SoftgenCsfHelper::typography( '.post-items.classic article .entry-footer .post-comments', $this->array_key_exists( 'comments_typo', $styles_data ) );
                $data .= $this->output_single( '.post-items.classic article .entry-footer .post-comments i', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'comments_icon_color', $styles_data ) ) );
                $data .= $this->output_single( '.post-items.classic article .entry-footer .post-comments:hover', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'comments_hover_color', $styles_data ) ) );
            }
        }
        return $data;
    }

    /**
     * Font Styles
     *
     * @return string
     */
    public function font_styles() {
        $heading_style = softgen_get_option( 'headings_fonts', 'no' );
        $text_style    = softgen_get_option( 'text_fonts', 'no' );
        $data          = '';
        $tablet_data   = '';
        $mobile_data   = '';

        if ( 'yes' === $heading_style ) {
            $h1_styles_data = softgen_get_option( 'h1_style' );
            $tablet_data .= SoftgenCsfHelper::typography( 'h1,.h1', $this->array_key_exists( 't_typo', $h1_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 't_margin', $h1_styles_data ) ) );
            $mobile_data .= SoftgenCsfHelper::typography( 'h1,.h1', $this->array_key_exists( 'm_typo', $h1_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'm_margin', $h1_styles_data ) ) );
            $h2_styles_data = softgen_get_option( 'h2_style' );
            $tablet_data .= SoftgenCsfHelper::typography( 'h2,.h2', $this->array_key_exists( 't_typo', $h2_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 't_margin', $h2_styles_data ) ) );
            $mobile_data .= SoftgenCsfHelper::typography( 'h2,.h2', $this->array_key_exists( 'm_typo', $h2_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'm_margin', $h2_styles_data ) ) );
            $h3_styles_data = softgen_get_option( 'h3_style' );
            $tablet_data .= SoftgenCsfHelper::typography( 'h3,.h3', $this->array_key_exists( 't_typo', $h3_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 't_margin', $h3_styles_data ) ) );
            $mobile_data .= SoftgenCsfHelper::typography( 'h3,.h3', $this->array_key_exists( 'm_typo', $h3_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'm_margin', $h3_styles_data ) ) );
            $h4_styles_data = softgen_get_option( 'h4_style' );
            $tablet_data .= SoftgenCsfHelper::typography( 'h4,.h4', $this->array_key_exists( 't_typo', $h4_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 't_margin', $h4_styles_data ) ) );
            $mobile_data .= SoftgenCsfHelper::typography( 'h4,.h4', $this->array_key_exists( 'm_typo', $h4_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'm_margin', $h4_styles_data ) ) );
            $h5_styles_data = softgen_get_option( 'h5_style' );
            $tablet_data .= SoftgenCsfHelper::typography( 'h5,.h5', $this->array_key_exists( 't_typo', $h5_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 't_margin', $h5_styles_data ) ) );
            $mobile_data .= SoftgenCsfHelper::typography( 'h5,.h5', $this->array_key_exists( 'm_typo', $h5_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'm_margin', $h5_styles_data ) ) );
            $h6_styles_data = softgen_get_option( 'h6_style' );
            $tablet_data .= SoftgenCsfHelper::typography( 'h6,.h6', $this->array_key_exists( 't_typo', $h6_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 't_margin', $h6_styles_data ) ) );
            $mobile_data .= SoftgenCsfHelper::typography( 'h6,.h6', $this->array_key_exists( 'm_typo', $h6_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'm_margin', $h6_styles_data ) ) );
            $data .= SoftgenCsfHelper::typography( 'h1,.h1', $this->array_key_exists( 'd_typo', $h1_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'd_margin', $h1_styles_data ) ) );
            $mobile_data .= SoftgenCsfHelper::typography( 'h1,.h1', $this->array_key_exists( 'm_typo', $h1_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'm_margin', $h1_styles_data ) ) );
            $data .= SoftgenCsfHelper::typography( 'h2,.h2', $this->array_key_exists( 'd_typo', $h2_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'd_margin', $h2_styles_data ) ) );
            $data .= SoftgenCsfHelper::typography( 'h3,.h3', $this->array_key_exists( 'd_typo', $h3_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'd_margin', $h3_styles_data ) ) );
            $data .= SoftgenCsfHelper::typography( 'h4,.h4', $this->array_key_exists( 'd_typo', $h4_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'd_margin', $h4_styles_data ) ) );
            $data .= SoftgenCsfHelper::typography( 'h5,.h5', $this->array_key_exists( 'd_typo', $h5_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'd_margin', $h5_styles_data ) ) );
            $data .= SoftgenCsfHelper::typography( 'h6,.h6', $this->array_key_exists( 'd_typo', $h6_styles_data ), '', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'd_margin', $h6_styles_data ) ) );
        }

        if ( 'yes' === $text_style ) {
            $p_styles_data = softgen_get_option( 'paragraph_style' );
            $data .= SoftgenCsfHelper::typography( 'body, p', $this->array_key_exists( 'd_typo', $p_styles_data ) );
            $data .= $this->output_single( 'p', SoftgenCsfHelper::spacing( 'margin', $this->array_key_exists( 'd_margin', $p_styles_data ) ) );
            $tablet_data .= SoftgenCsfHelper::typography( 'body, p', $this->array_key_exists( 't_typo', $p_styles_data ) );
            $mobile_data .= SoftgenCsfHelper::typography( 'body, p', $this->array_key_exists( 'm_typo', $p_styles_data ) );
        }
        $tablet = $this->media_query( '992px', 'max', $tablet_data );
        $mobile = $this->media_query( '767px', 'max', $mobile_data );
        return $data . $tablet . $mobile;
    }

    /**
     * Pagination styles
     *
     * @return string
     */
    public function pagination_styles() {
        $custom_style = softgen_get_option( 'pagination_custom_style', 'no' );
        $data         = '';
        if ( 'yes' === $custom_style ) {
            $styles_data = softgen_get_option( 'pagi_styles' );
            $data .= $this->output_single( '.navigation.pagination', SoftgenCsfHelper::spacing( 'margin', softgen_get_option( 'pagi_spacing' ) ) );
            $data .= $this->output_single( '.navigation.pagination .nav-links', 'justify-content:' . softgen_get_option( 'pagi_alignment', 'flex-start' ) . ';' );
            $data .= $this->output_single( '.navigation.pagination .nav-links', SoftgenCsfHelper::slider( 'column-gap', $this->array_key_exists( 'space_between_item', $styles_data ) ) );
            $data .= SoftgenCsfHelper::background( '.navigation.pagination .nav-links a', $this->array_key_exists( 'bg_normal', $styles_data ) );
            $data .= SoftgenCsfHelper::typography( '.navigation.pagination .nav-links a, .navigation.pagination .nav-links span.page-numbers.current', $this->array_key_exists( 'typography', $styles_data ) );
            $data .= SoftgenCsfHelper::background( '.navigation.pagination .nav-links a:before, .navigation.pagination .nav-links span.page-numbers.current', $this->array_key_exists( 'bg_hover', $styles_data ) );
            $data .= $this->output_single( '.navigation.pagination .nav-links a:hover, .navigation.pagination .nav-links span.page-numbers.current', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'hover_color', $styles_data ) ) );
        }
        return $data;
    }

    /**
     * ScrollToTop Styles 
     *
     * @return string
     */
    public function srolltotop_styles() {
        $data = '';
        if( 'enable' === softgen_get_option('gototop_btn', 'disable') ) {
            $data .= SoftgenCsfHelper::background( '#scroll-to-top', softgen_get_option('scrolltop_bg_color'), [
                SoftgenCsfHelper::color( 'color', softgen_get_option('scrolltop_icon_color') ),
                SoftgenCsfHelper::slider( 'font-size', softgen_get_option( 'scrolltop_icon_size' ), 'px' )
            ] );
        }
        return $data;
    }

    /**
     * Preloader Styles 
     *
     * @return string
     */
    public function preloader_styles() {
        $preloader_style = softgen_get_option( 'preloader_style', 'default' );
        $data = '';
        $data .= $this->output_single( '#preloader-wrap', SoftgenCsfHelper::color( 'background-color', softgen_get_option('preloader_bg') ) );
        if( 'default' === $preloader_style ) {
            $data .= $this->output_single( '#preloader-wrap .sg-loading span', SoftgenCsfHelper::color( 'color', softgen_get_option('preloader_text_color') ) );
            $data .= $this->output_single( '#preloader-wrap .sg-loading span:after', SoftgenCsfHelper::color( 'color', softgen_get_option('preloader_fill_color') ) );
        }elseif( 'spinner' === $preloader_style ) {
            $data .= $this->output_single( '#preloader-wrap .sg-spinner', SoftgenCsfHelper::color( 'background-color', softgen_get_option('preloader_circle_color') ) );
        }
        return $data;
    }

    /**
     * Footer Styles
     *
     * @return void
     */
    public function footer_styles() {
        $data             = '';
        $footer_content   = softgen_get_option( 'footer-content' );
        $footer_top       = $this->array_key_exists( 'footer-widget', $footer_content );
        $footer_border    = $this->array_key_exists( 'footer-widget-bd', $footer_content );
        $footer_spacing_d = $this->array_key_exists( 'footer-w-spacing-d', $footer_content );
        $global_gradient_bg = $this->array_key_exists( 'footer_gradient_bg', $footer_content );
        $copyright_border = $this->array_key_exists( 'footer-copyright-bd', $footer_content );
        $copyright_spacing = $this->array_key_exists( 'footer-spacing-d', $footer_content );
        
        if( 'custom' != $global_gradient_bg ) {
            $data .= self::output_single( '.footer-wrapper', 'background-image: url('. get_template_directory_uri() .'/assets/img/gradient/'. $global_gradient_bg .'.jpg)' );
        }else{
            $data .= SoftgenCsfHelper::background( '.footer-wrapper', $this->array_key_exists( 'footer-widget-bg', $footer_content ) );
        }

        if ( 'show' === $footer_top ) {
            $data .= $this->output( 'div.footer-widgets-area', [SoftgenCsfHelper::border( $footer_border ), SoftgenCsfHelper::spacing( 'padding', $footer_spacing_d )] );
        }

        if( 'show' != $footer_top ) {
            $data .= SoftgenCsfHelper::background( '.no-widget-area .copyright-area', $this->array_key_exists( 'footer-copyright-bg', $footer_content ),
            [SoftgenCsfHelper::border( $copyright_border )] );
        }

        $data .= SoftgenCsfHelper::background( '.copyright-area .copyright-inner', $this->array_key_exists( 'footer-copyright-bg', $footer_content ),
            [SoftgenCsfHelper::border( $copyright_border ), SoftgenCsfHelper::spacing( 'padding', $copyright_spacing )] );
        $data .= $this->output_single( '.copyright-area .copyright-inner,.copyright-area .site-info a,.footer-menu li a', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'footer-txt-color', $footer_content ) ) );
        $data .= $this->output_single( '.copyright-area .site-info a:hover,.footer-menu li a:hover', SoftgenCsfHelper::color( 'color', $this->array_key_exists( 'footer-txt-link-color', $footer_content ) ) );
        return $data;
    }

    /**
     * CSS for Desktop
     *
     * @return string
     */
    public function desktop_css() {
        $data = '';

        $logo_width = softgen_get_option( 'softgen_logo_width' );
        if ( ! empty( $this->array_key_exists( 'top', $logo_width ) ) ) {
            $data .= $this->output_single( '.site-branding', 'width:' . $logo_width['top'] . $logo_width['unit'] . ';' );
        }

        return $this->media_query( '992px', 'min', $data );
    }

    /**
     * CSS for Tablet
     *
     * @return string
     */
    public function tablet_css() {
        $data             = '';
        $logo_width       = softgen_get_option( 'softgen_logo_width' );
        $footer_content   = softgen_get_option( 'footer-content' );
        $footer_spacing_t = $this->array_key_exists( 'footer-w-spacing-t', $footer_content );
        $copyright_spacing = $this->array_key_exists( 'footer-spacing-t', $footer_content );

        if ( ! empty( $this->array_key_exists( 'right', $logo_width ) ) ) {
            $data .= $this->output_single( '.site-branding', 'width:' . $logo_width['right'] . $logo_width['unit'] . ';' );
        }
        if ( 'default' === softgen_get_option( 'softgen_footer_template', 'default' ) ) {
            $data .= $this->output_single( 'div.footer-widgets-area', SoftgenCsfHelper::spacing( 'padding', $footer_spacing_t ) );
            $data .= $this->output_single( '.copyright-area .copyright-inner', SoftgenCsfHelper::spacing( 'padding', $copyright_spacing ) );
        }

        return $this->media_query( '992px', 'max', $data );
    }

    /**
     * CSS for Mobile
     *
     * @return string
     */
    public function mobile_css() {
        $data = '';

        $logo_width       = softgen_get_option( 'softgen_logo_width' );
        $footer_content   = softgen_get_option( 'footer-content' );
        $footer_spacing_m = $this->array_key_exists( 'footer-w-spacing-m', $footer_content );
        $copyright_spacing = $this->array_key_exists( 'footer-spacing-m', $footer_content );
        if ( ! empty( $this->array_key_exists( 'bottom', $logo_width ) ) ) {
            $data .= $this->output_single( '.site-branding', 'width:' . $logo_width['bottom'] . $logo_width['unit'] . ';' );
        }
        if ( 'default' === softgen_get_option( 'softgen_footer_template', 'default' ) ) {
            $data .= $this->output_single( 'div.footer-widgets-area', SoftgenCsfHelper::spacing( 'padding', $footer_spacing_m ) );
            $data .= $this->output_single( '.copyright-area .copyright-inner', SoftgenCsfHelper::spacing( 'padding', $copyright_spacing ) );
        }

        return $this->media_query( '767px', 'max', $data );
    }

    /**
     * Check the array key exists
     *
     * @param string $key
     * @param array $array
     * @return void
     */
    public function array_key_exists( $key = '', $array = [] ) {
        if ( is_array( $array ) ) {
            if ( array_key_exists( $key, $array ) ) {
                return $array[$key];
            } else {
                return '';
            }
        }
    }

    /**
     * CSS Output Single Poperty
     *
     * @param string $selectors
     * @param string $key
     * @param string $type color, spacing, border, dimensions
     * @return string
     */
    public function output_single( $selectors = '', $property = '' ) {
        if ( ! empty( $selectors && $property ) ) {
            return $selectors . '{' . $property . '}';
        } else {
            return '';
        }
    }

    /**
     * CSS Output Multi Poperty
     *
     * @param string $selectors
     * @param array $values
     * @return string
     */
    public function output( $selectors = '', $values = [] ) {
        $data = '';
        if ( ! empty( array_filter( $values ) && $selectors ) && is_array( $values ) ) {
            $data .= $selectors . '{';
            foreach ( $values as $value ) {
                $data .= $value;
            }
            $data .= '}';
        }
        return $data;
    }

    /**
     * Media Query
     *
     * @param string $v
     * @return void
     */
    public function media_query( $size = '992px', $minmax = 'min', $css_rules = '' ) {
        $data = "";
        if ( ! empty( $size && $css_rules && $minmax ) ) {
            $data .= "@media( {$minmax}-width: {$size} ){";
            $data .= $css_rules;
            $data .= "}";
        }
        return $data;
    }
}
new SoftgenCustomCSS();