<?php
defined( 'ABSPATH' ) || exit;
if ( class_exists( 'CSF' ) ) {

    $softgen_theme = wp_get_theme();
    $softgen_opt   = 'softgen_opt';

    // Config Options
    CSF::createOptions( $softgen_opt, array(
        'menu_title'      => esc_html__( 'Softgen Options', 'softgen' ),
        'framework_title' => '<img src="' . get_template_directory_uri() . '/assets/img/logo-light.png" alt="' . esc_attr( $softgen_theme->get( 'Name' ) ) . '" style="max-width: 165px">',
        'footer_credit'   => SoftgenHelper::kses_advance( 'Softgen created by <a href="' . esc_url( 'https://dynamiclayers.net' ) . '" target="_blank">DynamicLayers</a>.' ),
        'menu_slug'       => 'softgen',
        'menu_icon'       => 'dashicons-admin-generic',
        'sticky_header'   => true,
        'menu_position'   => 2,
        'footer_text'     => $softgen_theme->get( 'Name' ) . ' ' . esc_html__( 'Version', 'softgen' ) . ' ' . $softgen_theme->get( 'Version' ),
    ) );

    require get_template_directory() . '/inc/options/opt-general.php';
    require get_template_directory() . '/inc/options/opt-header.php';
    require get_template_directory() . '/inc/options/opt-layout.php';
    require get_template_directory() . '/inc/options/opt-fonts.php';
    require get_template_directory() . '/inc/options/opt-styles.php';
    require get_template_directory() . '/inc/options/opt-page-banner.php';
    require get_template_directory() . '/inc/options/opt-archive.php';
    require get_template_directory() . '/inc/options/opt-page.php';
    require get_template_directory() . '/inc/options/opt-blog.php';
    require get_template_directory() . '/inc/options/opt-projects.php';
    require get_template_directory() . '/inc/options/opt-404.php';
    require get_template_directory() . '/inc/options/opt-login-page.php';
    require get_template_directory() . '/inc/options/opt-socials.php';
    if ( class_exists( 'WooCommerce' ) ) {
        require get_template_directory() . '/inc/options/opt-woocommerce.php';
    }
    require get_template_directory() . '/inc/options/opt-footer.php';
    require get_template_directory() . '/inc/options/opt-tools.php';

    // Backup section
    CSF::createSection( $softgen_opt, array(
        'title'  => esc_html__( 'Export/Import', 'softgen' ),
        'icon'   => 'fa fa-database',
        'fields' => array(

            array(
                'type' => 'backup',
            ),

        ),
    ) );

    // CSF Helper
    require get_template_directory() . '/inc/csf-helper.php';
    // Custom CSS
    require get_template_directory() . '/inc/custom-css.php';
}

if ( ! function_exists( 'softgen_get_option' ) ) {
    function softgen_get_option( $option = '', $default = null ) {
        $options = get_option( 'softgen_opt' );
        return ( isset( $options[$option] ) ) ? $options[$option] : $default;
    }
}