<?php
defined( 'ABSPATH' ) || exit;
// General Section
CSF::createSection( 'softgen_opt', array(
    'id'    => 'general_sec',
    'title' => esc_html__( 'General', 'softgen' ),
    'icon'  => 'fa fa-cog',
) );

// Scroll Top
CSF::createSection( 'softgen_opt', array(
    'parent' => 'general_sec',
    'title'  => esc_html__( 'Scroll Top', 'softgen' ),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__( 'Scroll Top', 'softgen' ),
        ),
        array(
            'id'       => 'gototop_btn',
            'type'     => 'button_set',
            'title'    => esc_html__( 'Scroll To Top', 'softgen' ),
            'subtitle' => esc_html__( 'Enable scroll to top of your site.', 'softgen' ),
            'options'  => array(
                'enable'  => esc_html__( 'Enable', 'softgen' ),
                'disable' => esc_html__( 'Disable', 'softgen' ),
            ),
            'default'  => 'enable',
        ),

        array(
            'id'                    => 'scrolltop_bg_color',
            'type'                  => 'background',
            'title'                 => esc_html__( 'Background', 'softgen' ),
            'background_gradient'   => true,
            'background_image'      => false,
            'background_position'   => false,
            'background_repeat'     => false,
            'background_attachment' => false,
            'background_size'       => false,
            'dependency'            => array( 'gototop_btn', '==', 'enable' ),
        ),

        array(
            'id'          => 'scrolltop_icon_size',
            'type'        => 'slider',
            'title'       => esc_html__( 'Icon Size', 'softgen' ),
            'min'         => 8,
            'max'         => 50,
            'step'        => 1,
            'unit'        => 'px',
            'dependency'  => array( 'gototop_btn', '==', 'enable' ),
        ),

        array(
            'id'      => 'scrolltop_icon_color',
            'type'    => 'color',
            'title'   => esc_html__( 'Icon Color', 'softgen' ),
            'dependency'  => array( 'gototop_btn', '==', 'enable' ),
        ),

    ),
) );

// Smooth Scroll
CSF::createSection( 'softgen_opt', array(
    'parent' => 'general_sec',
    'title'  => esc_html__( 'Smooth Scroll', 'softgen' ),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__( 'Smooth Mouse Scroll', 'softgen' ),
        ),

        array(
            'id'       => 'smooth_scroll',
            'type'     => 'button_set',
            'title'    => esc_html__( 'Smooth Scroll', 'softgen' ),
            'subtitle' => esc_html__( 'You can enable or disable smooth mouse scroll using this option.', 'softgen' ),
            'options'  => array(
                'enable'  => esc_html__( 'Enable', 'softgen' ),
                'disable' => esc_html__( 'Disable', 'softgen' ),
            ),
            'default'  => 'disable',
        ),

    ),
) );

// Preloader
CSF::createSection( 'softgen_opt', array(
    'parent' => 'general_sec',
    'title'  => esc_html__( 'Preloader', 'softgen' ),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__( 'Preloader', 'softgen' ),
        ),

        array(
            'id'       => 'preloader_control',
            'type'     => 'select',
            'title'    => esc_html__( 'Preloader Control', 'softgen' ),
            'subtitle' => esc_html__( 'You can select from where preloader will show.', 'softgen' ),
            'options'  => array(
                'disable'   => esc_html__( 'Disable', 'softgen' ),
                'show_all'  => esc_html__( 'Show In All Page', 'softgen' ),
                'only_home' => esc_html__( 'Show In Only Homepage', 'softgen' ),
            ),
            'default'  => 'show_all',
        ),

        array(
            'id'       => 'preloader_style',
            'type'     => 'select',
            'title'    => esc_html__( 'Preloader Style', 'softgen' ),
            'subtitle' => esc_html__( 'You can select from where preloader will show.', 'softgen' ),
            'options'  => array(
                'default'   => esc_html__( 'Default', 'softgen' ),
                'spinner'  => esc_html__( 'Spinner', 'softgen' ),
                'custom' => esc_html__( 'Custom', 'softgen' ),
            ),
            'default'  => 'default',
            'dependency' => array( 'preloader_control', '!=', 'disable' ),
        ),

        array(
            'id'         => 'preloader_text',
            'type'       => 'text',
            'title'      => esc_html__( 'Preloader Text', 'softgen' ),
            'subtitle'   => esc_html__( 'You can change the preloader text from here.', 'softgen' ),
            'attributes' => array(
                'placeholder' => esc_html__( 'Preloader text...', 'softgen' ),
            ),
            'default'  => esc_html__( 'Softgen', 'softgen' ),
            'dependency' => array( 'preloader_control|preloader_style', '!=|==', 'disable|default' ),
        ),

        array(
            'id'           => 'custom_preloader_img',
            'type'         => 'media',
            'title'        => esc_html__( 'Custom Preloader', 'softgen' ),
            'subtitle'   => esc_html__( 'You can use a custom preloader image using this option.', 'softgen' ),
            'library'      => 'image',
            'placeholder'  => esc_html__( 'No Preloader selected', 'softgen' ),
            'button_title' => esc_html__( 'Upload Preloader', 'softgen' ),
            'remove_title' => esc_html__( 'Remove Preloader', 'softgen' ),
            'dependency' => array( 'preloader_control|preloader_style', '!=|==', 'disable|custom' ),
        ),

        array(
            'id'         => 'preloader_bg',
            'type'       => 'color',
            'title'      => esc_html__( 'Background Color', 'softgen' ),
            'subtitle'   => esc_html__( 'You can choose background color from here.', 'softgen' ),
            'dependency' => array( 'preloader_control', '!=', 'disable' ),
        ),

        array(
            'id'         => 'preloader_circle_color',
            'type'       => 'color',
            'title'      => esc_html__( 'Circle Color', 'softgen' ),
            'subtitle'   => esc_html__( 'You can change circle color from here.', 'softgen' ),
            'dependency' => array( 'preloader_control|preloader_style', '!=|==', 'disable|spinner' ),
        ),

        array(
            'id'         => 'preloader_text_color',
            'type'       => 'color',
            'title'      => esc_html__( 'Text Color', 'softgen' ),
            'subtitle'   => esc_html__( 'You can change the preloader text color from here.', 'softgen' ),
            'dependency' => array( 'preloader_control|preloader_style', '!=|==', 'disable|default' ),
        ),

        array(
            'id'         => 'preloader_fill_color',
            'type'       => 'color',
            'title'      => esc_html__( 'Text Fill Color', 'softgen' ),
            'subtitle'   => esc_html__( 'You can change the preloader text fill color from here.', 'softgen' ),
            'dependency' => array( 'preloader_control|preloader_style', '!=|==', 'disable|default' ),
        ),

    ),
) );

// Custom Cursor
CSF::createSection( 'softgen_opt', array(
    'parent' => 'general_sec',
    'title'  => esc_html__( 'Custom Cursor', 'softgen' ),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__( 'Custom Cursor', 'softgen' ),
        ),

        array(
            'id'       => 'custom_cursor',
            'type'     => 'button_set',
            'title'    => esc_html__( 'Custom Cursor', 'softgen' ),
            'subtitle' => esc_html__( 'You can show or hide custom cursor using this option.', 'softgen' ),
            'options'  => array(
                'show' => esc_html__( 'Show', 'softgen' ),
                'hide' => esc_html__( 'Hide', 'softgen' ),
            ),
            'default'  => 'show',
        ),

        array(
            'id'          => 'cursor_color',
            'type'        => 'color',
            'title'       => esc_html__( 'Cursor Color', 'softgen' ),
            'subtitle'    => esc_html__( 'You can change cursor color from here.', 'softgen' ),
            'output_mode' => 'background-color',
            'output'      => '.dl-cursor:before',
            'dependency'  => array( 'custom_cursor', '==', 'show' ),
        ),

    ),
) );

// Google Map API Key
CSF::createSection( 'softgen_opt', array(
    'parent' => 'general_sec',
    'title'  => esc_html__( 'Google Map API Key', 'softgen' ),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__( 'Google Map API Key', 'softgen' ),
        ),

        array(
            'id'          => 'google_map_api_key',
            'type'        => 'text',
            'title'       => esc_html__( 'Google Map API Key', 'softgen' ),
            'subtitle'    => esc_html__( 'Enter your google map API Key to use our Elementor Google Map widget.', 'softgen' ),
            'desc'        => esc_html__( 'Go to', 'softgen' ) . ' <a href="https://developers.google.com" target="_blank">https://developers.google.com</a> ' . esc_html__( 'and generate the API key.', 'softgen' ),
            'placeholder' => esc_html__( 'Google map API key...', 'softgen' ),
        ),

    ),
) );