<?php
defined('ABSPATH') || exit;

// Projects
CSF::createSection('softgen_opt', array(
    'id'    => 'project_sec',
    'title' => esc_html__('Projects', 'softgen'),
    'icon'  => 'dashicons-before dashicons-buddicons-topics',
));

// Page Banner
CSF::createSection('softgen_opt', array(
    'parent' => 'project_sec',
    'title'  => esc_html__('Page Banner', 'softgen'),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__('Page Banner', 'softgen'),
        ),

        array(
            'id'         => 'project_ph_text_align',
            'type'       => 'button_set',
            'title'      => esc_html__('Text Alignment', 'softgen'),
            'subtitle'   => esc_html__('You can change the text alignment using this option.', 'softgen'),
            'options'    => array(
                'left'   => esc_html__('Left', 'softgen'),
                'center' => esc_html__('Center', 'softgen'),
                'right'  => esc_html__('Right', 'softgen'),
            ),
            'default'    => 'center'
        ),

        array(
            'id'         => 'project_bg_img',
            'type'       => 'button_set',
            'title'      => esc_html__('Background Image Source', 'softgen'),
            'options'    => array(
                'featured_img'  => esc_html__('Featured Image', 'softgen'),
                'custom' => esc_html__('Custom', 'softgen')
            ),
            'default'    => 'custom'
        ),

        array(
            'id'        => 'project_ph_gradient_bg',
            'type'      => 'image_select',
            'title'    => esc_html__('Gradient Background', 'softgen'),
            'subtitle' => esc_html__('You can select gradient background from here.', 'softgen'),
            'options'   => array(
                'gradient-bg-1' => get_template_directory_uri() . '/assets/img/gradient/gradient-thumb-1.jpg',
                'gradient-bg-2' => get_template_directory_uri() . '/assets/img/gradient/gradient-thumb-2.jpg',
                'gradient-bg-3' => get_template_directory_uri() . '/assets/img/gradient/gradient-thumb-3.jpg',
                'gradient-bg-4' => get_template_directory_uri() . '/assets/img/gradient/gradient-thumb-4.jpg',
                'custom' => get_template_directory_uri() . '/assets/img/gradient/custom.jpg',
            ),
            'default'   => 'gradient-bg-1',
            'dependency'    => array('project_bg_img', '!=', 'featured_img')
        ),

        array(
            'id'                       => 'project_ph_bg',
            'type'                     => 'background',
            'title'                    => esc_html__('Background Image', 'softgen'),
            'subtitle'                 => esc_html__('You can change the project page banner background image using this option.', 'softgen'),
            'background_blend_mode'    => false,
            'background_image_preview' => true,
            'dependency'               => array('project_bg_img|project_ph_gradient_bg', '!=|==', 'featured_img|custom')
        ),

        array(
            'id'                    => 'project_overlay_color',
            'type'                  => 'background',
            'title'                 => esc_html__('Overlay Color', 'softgen'),
            'background_gradient'   => true,
            'background_image'   => false,
            'background_position'   => false,
            'background_repeat'   => false,
            'background_attachment'   => false,
            'background_size'   => false,
            'background_image_preview'   => false,
            'dependency'    => array('project_bg_img', '!=', 'custom')
        )

    ),
));

// Project Details
CSF::createSection('softgen_opt', array(
    'parent' => 'project_sec',
    'title'  => esc_html__('Project Details', 'softgen'),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__('Project Details', 'softgen'),
        ),

        array(
            'id'       => 'project_navigation',
            'type'     => 'button_set',
            'title'    => esc_html__('Navigation', 'softgen'),
            'subtitle' => esc_html__('You can show or hide project navigation from the blog details page.', 'softgen'),
            'options'  => array(
                'show' => esc_html__('Show', 'softgen'),
                'hide' => esc_html__('Hide', 'softgen'),
            ),
            'default'  => 'show'
        ),

        array(
            'id'          => 'project_nav_btn_title',
            'type'        => 'text',
            'title'       => esc_html__('Nav Button Title', 'softgen'),
            'subtitle'    => esc_html__('You can enter the project navigation button title text using this field.', 'softgen'),
            'placeholder' => esc_html__('Title goes here..', 'softgen'),
            'default'     => esc_html__('View All Projects', 'softgen'),
            'dependency' => array('project_navigation', '!=', 'hide')
        ),

        array(
            'id'          => 'project_nav_btn_link',
            'type'        => 'text',
            'title'       => esc_html__('Nav Button Link', 'softgen'),
            'subtitle'    => esc_html__('You can enter the all projects link from this field. Default is project archive page link.', 'softgen'),
            'placeholder' => esc_html__('Link goes here..', 'softgen'),
            'dependency' => array('project_navigation', '!=', 'hide')
        ),

        array(
            'id'       => 'project_social_share',
            'type'     => 'button_set',
            'title'    => esc_html__('Social Share Buttons', 'softgen'),
            'subtitle' => esc_html__('You can show or hide project social share buttons using this option.', 'softgen'),
            'options'  => array(
                'show' => esc_html__('Show', 'softgen'),
                'hide' => esc_html__('Hide', 'softgen'),
            ),
            'default'  => 'show'
        ),

        array(
            'id'       => 'project_comments',
            'type'     => 'button_set',
            'title'    => esc_html__('Comments', 'softgen'),
            'subtitle' => esc_html__('You can show or hide project comment using this option.', 'softgen'),
            'options'  => array(
                'show' => esc_html__('Show', 'softgen'),
                'hide' => esc_html__('Hide', 'softgen'),
            ),
            'default'  => 'hide'
        ),

    ),
));

// Related Projects
CSF::createSection('softgen_opt', array(
    'parent' => 'project_sec',
    'title'  => esc_html__('Related Projects', 'softgen'),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__('Related Project', 'softgen'),
        ),

        array(
            'id'       => 'related_project',
            'type'     => 'button_set',
            'title'    => esc_html__('Related Projects', 'softgen'),
            'subtitle' => esc_html__('You can show or hide related projects section using this option.', 'softgen'),
            'options'  => array(
                'show' => esc_html__('Show', 'softgen'),
                'hide' => esc_html__('Hide', 'softgen'),
            ),
            'default'  => 'show'
        ),

        array(
            'id'          => 'rel_project_title',
            'type'        => 'text',
            'title'       => esc_html__('Title', 'softgen'),
            'subtitle'    => esc_html__('You can enter the related project section title text using this field.', 'softgen'),
            'placeholder' => esc_html__('Title goes here..', 'softgen'),
            'default'     => esc_html__('Related Projects', 'softgen'),
            'dependency' => array('related_project', '!=', 'hide')
        ),

        array(
            'id'          => 'rel_project_description',
            'type'        => 'textarea',
            'title'       => esc_html__('Description', 'softgen'),
            'subtitle'    => esc_html__('You can enter the related project section description text using this field.', 'softgen'),
            'placeholder' => esc_html__('Description goes here..', 'softgen'),
            'default'     => esc_html__('Our success in creating business solutions is due in large part to our talented and highly committed team.', 'softgen'),
            'dependency' => array('related_project', '!=', 'hide')
        ),

        array(
            'id'          => 'rel_view_btn_label',
            'type'        => 'text',
            'title'       => esc_html__('View All Button Label', 'softgen'),
            'subtitle'    => esc_html__('You can enter the view all button text using this field.', 'softgen'),
            'placeholder' => esc_html__('Text goes here..', 'softgen'),
            'default'     => esc_html__('View All Projects', 'softgen'),
            'dependency' => array('related_project', '!=', 'hide')
        ),

        array(
            'id'          => 'rel_view_btn_link',
            'type'        => 'text',
            'title'       => esc_html__('View All Button Link', 'softgen'),
            'subtitle'    => esc_html__('You can enter the view all button link using this field.', 'softgen'),
            'placeholder' => esc_html__('Link goes here..', 'softgen'),
            'default'     => '',
            'dependency' => array('related_project|rel_view_btn_label', '!=|!=', 'hide|')
        ),

        array(
            'id'      => 'rel_projects_limit',
            'type'    => 'slider',
            'title'   => esc_html__( 'Projects Limit', 'softgen' ),
            'subtitle' => esc_html__( 'Choose how many projects you want to show.', 'softgen' ),
            'min'     => 1,
            'max'     => 10,
            'step'    => 1,
            'default' => 4,
            'dependency' => array( 'related_project', '==', 'show' ),
        ),

        array(
            'id'          => 'rel_project_order_by',
            'type'        => 'select',
            'title'       => esc_html__( 'Related Projects - Order', 'softgen' ),
            'subtitle' => esc_html__( 'Sorting orderby related projects.', 'softgen' ),
            'options'     => array(
                'date' => esc_html__( 'By Date', 'softgen' ),
                'author' => esc_html__( 'By Author', 'softgen' ),
                'title' => esc_html__( 'By Title', 'softgen' ),
                'comment_count' => esc_html__( 'By Comment Count', 'softgen' ),
                'rand' => esc_html__( 'By Random', 'softgen' )
            ),
            'default'     => 'date',
            'dependency' => array( 'related_project', '==', 'show' )
        ),

        array(
            'id'          => 'rel_project_layout',
            'type'        => 'select',
            'title'       => esc_html__('Layout Mode', 'softgen'),
            'subtitle'   => esc_html__('You can control column item for desktop from this field.', 'softgen'),
            'options'     => array(
                'carousel'  => esc_html__('Carousel', 'softgen'),
                'column'  => esc_html__('Column', 'softgen')
            ),
            'default'     => 'carousel',
            'dependency' => array('related_project', '!=', 'hide')
        ),

    ),
));

// Archive Page
CSF::createSection('softgen_opt', array(
    'parent' => 'project_sec',
    'title'  => esc_html__('Archive Page', 'softgen'),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__('Archive Page Banner', 'softgen'),
        ),

        array(
            'id'                       => 'project_a_page_banner_bg',
            'type'                     => 'background',
            'title'                    => esc_html__('Background Image', 'softgen'),
            'subtitle'                 => esc_html__('You can change the service page banner background image using this option.', 'softgen'),
            'background_blend_mode'    => false,
            'background_image_preview' => true
        ),

        array(
            'id'                    => 'project_a_overlay_color',
            'type'                  => 'background',
            'title'                 => esc_html__('Overlay Color', 'softgen'),
            'background_gradient'   => true,
            'background_image'   => false,
            'background_position'   => false,
            'background_repeat'   => false,
            'background_attachment'   => false,
            'background_size'   => false,
            'background_image_preview'   => false
        )

    ),
));
