<?php
/**
 * Related Items
 *
 * @package softgen
 */

defined( 'ABSPATH' ) || die();

class SoftgenRelatedItems{

    /**
     * Get related posts
     *
     * @param array $args
     * @return void
     */
    static function post( $args = [] ) {
        global $post;
        $title = softgen_get_option( 'rel_posts_title', esc_html__( 'You May Also Like', 'softgen' ) );

        // default args
        $args = wp_parse_args( $args, array(
            'post_id'   => ! empty( $post ) ? $post->ID : '',
            'taxonomy'  => softgen_get_option( 'rel_post_query_by', 'category' ),
            'limit'     => softgen_get_option( 'rel_posts_limit', 2 ),
            'post_type' => ! empty( $post ) ? $post->post_type : 'post',
            'orderby'   => softgen_get_option( 'rel_post_order_by', 'date' ),
            'order'     => 'DESC',
        ) );

        // check taxonomy
        if ( ! taxonomy_exists( $args['taxonomy'] ) ) {
            return;
        }

        // post taxonomies
        $taxonomies = wp_get_post_terms( $args['post_id'], $args['taxonomy'], array( 'fields' => 'ids' ) );

        if ( empty( $taxonomies ) ) {
            return;
        }

        // query
        $related_posts = get_posts( array(
            'post__not_in'   => (array) $args['post_id'],
            'post_type'      => $args['post_type'],
            'tax_query'      => array(
                array(
                    'taxonomy' => $args['taxonomy'],
                    'field'    => 'term_id',
                    'terms'    => $taxonomies,
                ),
            ),
            'posts_per_page' => $args['limit'],
            'orderby'        => $args['orderby'],
            'order'          => $args['order'],
        ) );

        if ( ! empty( $related_posts ) ) { ?>
            
            <div class="related-posts-wrapper">
                <?php if( ! empty( $title ) ) {
                    echo '<h3 class="post-footer-title">'. SoftgenHelper::kses_advance( $title ) .'</h3>';
                } ?>
                <div class="rel-items">
                <?php
                foreach ( $related_posts as $post ) {
                    setup_postdata( $post );
                    ?>
                    <div class="rel-post-card">
                        <div class="post-thumb">
                            <a class="title" href="<?php the_permalink();?>" title="<?php the_title_attribute();?>">
                                <?php 
                                if ( has_post_thumbnail() ) {
                                    echo get_the_post_thumbnail( null, 'medium_large', array( 'alt' => the_title_attribute( array( 'echo' => false ) ) ) );
                                }else{
                                    echo '<img src="'. get_template_directory_uri() .'/assets/img/no_image.jpg" alt="'. esc_attr( get_the_title() ) .'"/>';
                                }
                                ?>
                            </a>
                            <?php SoftgenHelper::get_terms( 'category' ); ?>
                        </div>
                        <div class="post-content">
                            <header class="entry-header">
                                <div class="post-meta">
                                <?php
                                    self::get_author();
                                    self::posted_on(); ?>
                                </div>
                                <h2 class="entry-title"><a href="<?php the_permalink();?>" rel="bookmark"><?php the_title(); ?></a></h2>
                            </header>
                            <footer class="entry-footer">
                                <a href="<?php the_permalink();?>" class="readmore"><?php esc_html_e( 'Read More', 'softgen' ); ?></a>
                                <?php
                                if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
                                    ?>
                                    <a class="post-comments" href="<?php comments_link(); ?>">
                                        <i class="dl dl-comments"></i>
                                        <?php 
                                        comments_number( 
                                            esc_html__( 'No Comments', 'softgen' ), 
                                            esc_html__( '1 Comment', 'softgen' ), 
                                            esc_html__( '% Comments', 'softgen' ) 
                                        ); 
                                        ?>
                                    </a>
                                    <?php
                                }
                                ?>
                            </footer>
                        </div>
                    </div>
                    <?php
                }
                ?>
                </div>
            </div>
            <?php
        }
        wp_reset_postdata();

    }

    /**
     * Get related projects
     *
     * @param array $args
     * @return void
     */
    static function project( $args = [] ) {
        global $post;
        $title = softgen_get_option( 'rel_project_title', esc_html__( 'Related Projects', 'softgen' ) );
        $desc = softgen_get_option( 'rel_project_description' );
        $btn_label = softgen_get_option( 'rel_view_btn_label' );
        $btn_link = softgen_get_option( 'rel_view_btn_link' );
        $layout_mode = 'carousel' === softgen_get_option('rel_project_layout', 'carousel' ) ? 'related-project-carousel owl-carousel' : 'related-project-column';
        $rel_source = SoftgenHelper::get_meta_field('based_on');
        $custom_rel_items = SoftgenHelper::get_meta_field('related_projects');

        $items = [];
        if( $rel_source === 'custom' ) {
            $items = $custom_rel_items;
        }else{
            // default args
            $args = wp_parse_args( $args, array(
                'post_id'   => ! empty( $post ) ? $post->ID : '',
                'taxonomy'  => 'project-category',
                'limit'     => softgen_get_option( 'rel_projects_limit', 4 ),
                'post_type' => ! empty( $post ) ? $post->post_type : 'dl-project',
                'orderby'   => softgen_get_option( 'rel_project_order_by', 'date' ),
                'order'     => 'DESC',
            ) );

            // check taxonomy
            if ( ! taxonomy_exists( $args['taxonomy'] ) ) {
                return;
            }

            // post taxonomies
            $taxonomies = wp_get_post_terms( $args['post_id'], $args['taxonomy'], array( 'fields' => 'ids' ) );

            if ( empty( $taxonomies ) ) {
                return;
            }

            // query
            $related_projects = get_posts( array(
                'post__not_in'   => (array) $args['post_id'],
                'post_type'      => $args['post_type'],
                'tax_query'      => array(
                    array(
                        'taxonomy' => $args['taxonomy'],
                        'field'    => 'term_id',
                        'terms'    => $taxonomies,
                    ),
                ),
                'posts_per_page' => $args['limit'],
                'orderby'        => $args['orderby'],
                'order'          => $args['order'],
            ) );
            $items = $related_projects;
        }

        if ( ! empty( $items ) ) {
            if( 'carousel' != softgen_get_option('rel_project_layout', 'carousel' ) ) {
                $total_project = new ArrayObject($items);
                $total_project_count = $total_project->count();
                $total_project_count_check = $total_project_count > 1 && $total_project_count <= 4 ? '--softgen-rel-project-col: ' . $total_project_count : '';
            }else{
                $total_project_count_check = '';
            }
            ?>
            <section class="related-projects-wrap">
                <div class="container">
                    <div class="rel-project-head">
                        <div class="rel-heading">
                            <h2 class="rel-title"><?php echo esc_html( $title ); ?></h2>
                            <?php
                            if( ! empty( $desc ) ) {
                                echo '<div class="rel-desc">'. SoftgenHelper::kses_basic( $desc ) .'</div>';
                            }
                            ?>
                        </div>
                        <?php
                        if( ! empty( $btn_label && $btn_link ) ) {
                            echo '<a href="'. esc_url( $btn_link ) .'" class="default-btn">'. esc_html( $btn_label ) .'</a>';
                        }
                        ?>
                    </div>
                    <div class="<?php echo esc_attr( $layout_mode ); ?>" style="<?php echo esc_attr( $total_project_count_check ); ?>">
                    <?php
                        foreach ( $items as $item ) {
                            if( $rel_source === 'custom' ) {
                                self::get_project_card( $item );
                            }else{
                                self::get_project_card( $item->ID );
                            }
                        }
                    ?>
                    </div>
                </div>
            </section>
            <?php
        }
        wp_reset_postdata();

    }

    /**
     * Get Post Date
     *
     * @return void
     */
    static function posted_on() {
        $archive_year  = get_the_time( 'Y' );
        $archive_month = get_the_time( 'm' );
        $archive_day   = get_the_time( 'd' );
        $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
        if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
        }
        $time_string = sprintf(
            $time_string,
            esc_attr( get_the_date( DATE_W3C ) ),
            esc_html( get_the_date('M j, Y') ),
            esc_attr( get_the_modified_date( DATE_W3C ) ),
            esc_html( get_the_modified_date( 'M j, Y' ) )
        );
        echo '<a href="' . esc_url( get_day_link( $archive_year, $archive_month, $archive_day ) ) . '" rel="bookmark"><i class="dl dl-calendar"></i>' . $time_string . '</a>';
    }

    /**
     * Get post author
     *
     * @return void
     */
    static function get_author() {
        $author_id = get_the_author_meta( 'ID' );
        if ( empty( $author_id ) && ! empty( $GLOBALS['post']->post_author ) ) {
            $author_id = $GLOBALS['post']->post_author;
        }
        if ( $author_id > 0 ) {
            $author_link   = get_author_posts_url( $author_id );
            $author_name   = get_the_author_meta( 'display_name', $author_id );
            echo '<a href="'. esc_url( $author_link ) .'" class="author"><i class="dl dl-user"></i>'. esc_html( $author_name ) .'</a>';
        }
    }

    /**
     * Project Card
     */
    static function get_project_card( $post_id ) {
        if( empty( $post_id ) && ! has_post_thumbnail() ) { return; }
        ?>
        <article id="project-<?php echo esc_attr( $post_id ); ?>" <?php post_class( 'project-card', $post_id ); ?>>
            <div class="project-card-inner">
                <div class="project-thumb">
                    <a href="<?php the_permalink( $post_id ); ?>"><?php echo get_the_post_thumbnail($post_id, 'softgen-project-350x400'); ?></a>
                </div>
                <div class="project-content">
                    <?php SoftgenHelper::get_terms('project-category', 1, true, 'project-cat', false, $post_id); ?>
                    <h3 class="project-title"><a href="<?php the_permalink( $post_id ); ?>"><?php echo get_the_title( $post_id ); ?></a></h3>
                    <a href="<?php the_permalink( $post_id ); ?>" class="read-more"><i class="las la-long-arrow-alt-right"></i></a>
                </div>
            </div>
        </article>
        <?php
    }
}