<?php
/**
 * Template hooks for this theme
 *
 * @package softgen
 */

// Header
function softgen_header_hook() {
    get_template_part( 'global-templates/header' );
}
add_action( 'softgen_header', 'softgen_header_hook' );

// Header Site Branding
function softgen_header_site_branding() {
    $sticky = softgen_get_option( 'header_sticky', 'enable' );
    $is_sticky = 'enable' === $sticky ? 'is-sticky-logo' : '';
    $custom_logo     = SoftgenHelper::get_meta_field( 'softgen_custom_logo' );
    $site_logo       = get_theme_mod( 'custom_logo' );
    $site_logo_url   = ! empty( $site_logo ) ? wp_get_attachment_url( $site_logo ) : '';
    $retina_logo     = SoftgenHelper::get_retina_logo( 'softgen_retina_logo' );
    $fallback_logo   = get_template_directory_uri() . '/assets/img/logo.png';
    if ( ! empty( $custom_logo ) ) {
        $logo_url = $custom_logo;
    } else {
        if ( ! has_custom_logo() ) {
            $logo_url = $fallback_logo;
        } else {
            $logo_url = $site_logo_url;
        }
    }
    echo '<img class="'. $is_sticky .'" src="' . esc_url( $logo_url ) . '" ' . wp_kses( $retina_logo, SoftgenHelper::get_allowed_html_tags( 'intermediate' ) ) . ' alt="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '"/>';
    if( 'enable' === $sticky ) {
        echo '<img class="sticky-logo" src="' . esc_url( SoftgenHelper::get_sticky_logo_url() ) . '" ' . wp_kses( $retina_logo, SoftgenHelper::get_allowed_html_tags( 'intermediate' ) ) . ' alt="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '"/>';
    }
}
add_action( 'softgen_site_branding', 'softgen_header_site_branding' );

// Single Post Banner
function softgen_single_post_banner() {
    get_template_part( 'global-templates/post', 'banner' );
}
add_action( 'softgen_single_post_banner', 'softgen_single_post_banner' );

// Page Banner
function softgen_page_banner() {
    if ( ! is_single() && ! is_404() ) {
        $global_visibility = softgen_get_option( 'ph_visibility', 'show' );
        if ( is_page() ) {
            $ph_visibility = SoftgenHelper::get_meta_field( 'softgen_page_header', 'default' );
            if ( 'default' != $ph_visibility ) {
                if ( 'show' === $ph_visibility ) {
                    get_template_part( 'global-templates/page', 'banner' );
                }
            } else {
                if ( 'show' === $global_visibility ) {
                    get_template_part( 'global-templates/page', 'banner' );
                }
            }
        } else {
            if ( 'show' === $global_visibility ) {
                get_template_part( 'global-templates/page', 'banner' );
            }
        }
    }
}
add_action( 'softgen_page_banner', 'softgen_page_banner' );

// Single Post Banner
function softgen_single_project_banner() {
    get_template_part( 'global-templates/project', 'banner' );
}
add_action( 'softgen_single_project_banner', 'softgen_single_project_banner' );

// Social Share
function softgen_social_share() {
    $softgen_pin_img = ! empty( SoftgenHelper::get_featured_image_url() ) ? 'data-image="'. esc_url( SoftgenHelper::get_featured_image_url() ) .'"' : '';
    $title = get_the_title();
    $tw_hastag = '';
    $fb_hastag = '';
    $pin_img = $softgen_pin_img;
    if( is_single() ) {
        $title = ! empty( SoftgenHelper::get_field('dl_description') ) ? SoftgenHelper::get_field('dl_description') : get_the_title();
        $hastags = SoftgenHelper::get_field('dl_hashtags');
        $tw_hastag = ! empty( $hastags ) ? ' data-hashtags="'. $hastags .'"' : '';
        if( ! empty( $hastags ) ) {
            $hastags_arr = preg_split ("/\,/", $hastags);
            $fb_hastag = ' data-hashtag="'. $hastags_arr[0] .'"';
        }
        $pin_img = SoftgenHelper::get_field('dl_pinterest_image');
        if( ! empty( $pin_img ) ) {
            $softgen_pin_img = 'data-image="'. $pin_img .'"';
        }
    }
    ?>
    <div class="post-social-share brand-color">
        <div class="facebook cursor-effect sound-effect" data-sharer="facebook"<?php echo SoftgenHelper::kses_advance( $fb_hastag ); ?> data-url="<?php the_permalink(); ?>" data-title="<?php echo esc_attr( $title ); ?>"><i class="la la-facebook"></i></div>
        <div class="twitter cursor-effect sound-effect" data-sharer="twitter"<?php echo SoftgenHelper::kses_advance( $tw_hastag ); ?>  data-title="<?php echo esc_attr( $title ); ?>" data-url="<?php the_permalink(); ?>"><i class="la la-twitter"></i></div>
        <div class="pinterest cursor-effect sound-effect" data-sharer="pinterest" data-description="<?php echo esc_attr( $title ); ?>" data-url="<?php the_permalink(); ?>" <?php echo SoftgenHelper::kses_advance( $softgen_pin_img ); ?>><i class="la la-pinterest-p"></i></div>
        <div class="linkedin cursor-effect sound-effect" data-sharer="linkedin" data-url="<?php the_permalink(); ?>" data-title="<?php echo esc_attr( $title ); ?>"><i class="la la-linkedin"></i></div>
    </div>
    <?php
}
add_action( 'softgen_social_share', 'softgen_social_share' );

/**
 * 404 Page Template Action
 *
 * @return void
 */
function softgen_404_page_template() {
    $template = softgen_get_option( 'softgen_404_template', 'default' );
    if ( 'default' === $template ) {
        get_template_part( 'global-templates/404', 'template' );
    } else {
        $el_block = softgen_get_option( 'softgen_404_el' );
        if ( ! empty( $el_block ) ) {
            SoftgenHelper::loop_by_id( $el_block, 'elementor_library' );
        } else {
            get_template_part( 'global-templates/404', 'template' );
        }
    }
}
add_action( 'softgen_404_page_template', 'softgen_404_page_template' );

/**
 * softgen Footer Hook
 *
 * @return void
 */
function softgen_footer() {
    $page_footer = SoftgenHelper::get_field( 'softgen_template_style' );
    $el_template = SoftgenHelper::get_field( 'softgen_el_template' );
    if ( 'default' != $page_footer ) {
        if ( ! empty( $el_template ) ) {
            SoftgenHelper::loop_by_id( $el_template, 'elementor_library' );
        } else {
            do_action( 'softgen_footer_template' );
        }
    } else {
        do_action( 'softgen_footer_template' );
    }
}
add_action( 'softgen_footer', 'softgen_footer' );

/**
 * Footer template
 *
 * @return void
 */
function softgen_footer_template() {
    $footer_template = softgen_get_option( 'softgen_footer_template', 'default' );
    $el_template     = softgen_get_option( 'softgen_el_template' );
    if ( 'default' === $footer_template ) {
        get_template_part( 'global-templates/footer-widget', 'template' );
    } else {
        if ( ! empty( $el_template ) ) {
            SoftgenHelper::loop_by_id( $el_template, 'elementor_library' );
        } else {
            get_template_part( 'global-templates/footer-widget', 'template' );
        }
    }

}
add_action( 'softgen_footer_template', 'softgen_footer_template' );

/**
 * Preloader
 *
 * @return void
 */
function softgen_preloader_text_spit($text = 'Softgen') {
    $out = '';
    $split = str_split($text);
    foreach( $split as $char ) {
        $out .= '<span data-text="'. $char .'">'. $char .'</span>';
    }
    return $out;
}

function softgen_preloader() {
    if( 'show_all' === softgen_get_option('preloader_control', 'show_all') ) {
        softgen_get_preloader();
    } elseif( 'only_home' === softgen_get_option('preloader_control', 'show_all') ) {
        if( is_home() ) {
            softgen_get_preloader();
        }
    }
}
add_action( 'softgen_preloader', 'softgen_preloader' );

function softgen_get_preloader(){
    $preloader_style = softgen_get_option( 'preloader_style', 'default' );
    if( 'default' === $preloader_style ) {
        $preloader_text = softgen_get_option( 'preloader_text', esc_html__( 'Softgen', 'softgen' ) );
        echo '<div id="preloader-wrap"><div class="sg-preloader sg-loading">'. softgen_preloader_text_spit( esc_html( $preloader_text ) ) .'</div></div>';
    }elseif( 'custom' === $preloader_style ){
        $custom_preloader = ! empty( softgen_get_option( 'custom_preloader_img' )['url'] ) ? softgen_get_option( 'custom_preloader_img' )['url'] : get_template_directory_uri() .'/assets/img/logo.png';
        echo '<div id="preloader-wrap"><div class="sg-preloader sg-custom-loader"><img src="'. esc_url( $custom_preloader ) .'" alt="'. esc_attr( get_bloginfo( 'name' ) ) .'"></div></div>';
    }else{
        echo '<div id="preloader-wrap"><div class="sg-preloader sg-spinner"></div></div>';
    }
}



/**
 * Header Cart Button
 *
 * @return void
 */
function softgen_header_cart_btn() {
    ?>
    <div class="dl-shopping-cart-btn cursor-effect">
        <span class="shopping-cart-inner">
            <span class="count softgen-cart-count">0</span>
            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32"><path d="M 16 3 C 13.253906 3 11 5.253906 11 8 L 11 9 L 6.0625 9 L 6 9.9375 L 5 27.9375 L 4.9375 29 L 27.0625 29 L 27 27.9375 L 26 9.9375 L 25.9375 9 L 21 9 L 21 8 C 21 5.253906 18.746094 3 16 3 Z M 16 5 C 17.65625 5 19 6.34375 19 8 L 19 9 L 13 9 L 13 8 C 13 6.34375 14.34375 5 16 5 Z M 7.9375 11 L 11 11 L 11 14 L 13 14 L 13 11 L 19 11 L 19 14 L 21 14 L 21 11 L 24.0625 11 L 24.9375 27 L 7.0625 27 Z"></path></svg>
        </span>
    </div>
    <?php
}

/**
 * Header cart button action
 *
 * @return void
 */
function softgen_header_cart_btn_action() {
    if( class_exists('WooCommerce') ) {
        if ( apply_filters( 'woocommerce_widget_cart_is_hidden', is_cart() || is_checkout() ) ) {
            return;
        }
        $woo_cart = softgen_get_option( 'woo_cart', 'all' );
        if( 'all' === $woo_cart ) {
            softgen_header_cart_btn();
        }elseif( 'woo' === $woo_cart && ( is_woocommerce() || is_cart() || is_checkout() || is_account_page() ) ) {
            softgen_header_cart_btn();
        }
    }
}
add_action( 'softgen_header_cart', 'softgen_header_cart_btn_action' );

/**
 * Header cart view
 *
 * @return void
 */
function softgen_header_cart_view() {
    $woo_cart = softgen_get_option( 'woo_cart','all' );
    if( class_exists('WooCommerce') ) {
        if ( apply_filters( 'woocommerce_widget_cart_is_hidden', is_cart() || is_checkout() ) ) {
            return;
        }
        if( 'all' === $woo_cart ) {
            get_template_part('global-templates/cart', 'overlay');
        }elseif( 'woo' === $woo_cart  && ( is_woocommerce() || is_cart() || is_checkout() || is_account_page() ) ) {
            get_template_part('global-templates/cart', 'overlay');
        }
    }
}
add_action( 'softgen_header_cart_view', 'softgen_header_cart_view' );