<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package softgen
 */

get_header();
$softgen_post_style = softgen_get_option( 'blog_post_style', 'classic' );
$softgen_masonry = 'grid' === $softgen_post_style ? ' data-masonry=\'{"percentPosition": true }\'' : '';
$softgen_sidebar_args = [
	'global_layout' => softgen_get_option( 'theme_sidebar_layout', 'right-sidebar' ),
	'global_widget' => softgen_get_option( 'theme_sidebar_widget', 'right-sidebar' )
];
?>
<section class="wrapper">
	<div class="<?php SoftgenHelper::theme_layout(); ?>">
		<div class="dl-row <?php echo esc_attr( SoftgenSidebar::sidebar_status( $softgen_sidebar_args ) ) . ' blog-style-' . esc_attr( $softgen_post_style ); ?>">
			<main id="primary" class="site-main">
				<div class="post-items <?php echo esc_attr( $softgen_post_style ); ?>"<?php echo wp_kses( $softgen_masonry, SoftgenHelper::get_allowed_html_tags() ); ?>>
				<?php
				if ( have_posts() ) :

					/* Start the Loop */
					while ( have_posts() ) :
						the_post();

						/*
						* Include the Post-Type-specific template for the content.
						* If you want to override this in a child theme, then include a file
						* called content-___.php (where ___ is the Post Type name) and that will be used instead.
						*/
						get_template_part( 'template-parts/content', get_post_type() );

					endwhile;

				else :

					get_template_part( 'template-parts/content', 'none' );

				endif;
				?>
				</div><!-- .post-items -->
				<?php softgen_the_posts_navigation(); ?>
			</main><!-- #main -->

			<?php get_sidebar(); ?>

		</div><!-- .dl-row -->
	</div><!-- .container -->
</section>
<?php
get_footer();
