<?php
/**
 * The template for displaying single project
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package softgen
 */

get_header();
$softgen_alignment = ' ' . softgen_get_option( 'project_ph_text_align', 'center' );
$softgen_sub_heading = SoftgenHelper::get_meta_field( 'sub_heading' );
$softgen_heading = SoftgenHelper::get_meta_field( 'big_heading' );
$softgen_desc = SoftgenHelper::get_meta_field( 'short_description' );
$softgen_project_heading = SoftgenHelper::get_meta_field( 'project_info_heading' );
$softgen_project_desc = SoftgenHelper::get_meta_field( 'project_info_desc' );
$softgen_project_info = ! empty( SoftgenHelper::get_meta_field( 'project_info' ) ) ? SoftgenHelper::get_meta_field( 'project_info' ) : [];
$softgen_bg_img = '';
if( 'featured_img' === softgen_get_option('project_bg_img', 'featured_img') ) {
	$softgen_bg_img_src = wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'full' );
	$softgen_bg_img_url = isset($softgen_bg_img_src[0]) ? $softgen_bg_img_src[0] : '';
	$softgen_bg_img = ! empty( $softgen_bg_img_url ) ? 'style="background-image: url('. $softgen_bg_img_url .')"' : '';
}
$softgen_p_info_cls = '' != $softgen_project_info ? ' is-info' : '';
$softgen_classes = $softgen_alignment . $softgen_p_info_cls;
?>

<section class="page-banner<?php echo esc_attr( $softgen_classes ); ?>" <?php echo SoftgenHelper::kses_basic( $softgen_bg_img ); ?>>
	<div class="<?php SoftgenHelper::theme_layout(); ?>">
		<div class="page-banner-inner">
			<div class="page-banner-info">
				<?php
					if( ! empty( $softgen_sub_heading ) ) {
						echo '<h4>'. esc_html( $softgen_sub_heading ) .'</h4>';
					}
					if( ! empty( $softgen_heading ) ){
						echo '<h1 class="entry-title">'. SoftgenHelper::kses_advance( SoftgenHelper::get_highlighted_text( $softgen_heading ) ) .'</h1>';
					}else{
						echo '<h1 class="entry-title">'. SoftgenHelper::kses_advance( get_the_title() ) .'</h1>';
					}
					if( ! empty( $softgen_desc ) ) {
						echo '<p>'. SoftgenHelper::kses_basic( $softgen_desc ) .'</p>';
					}else{
						echo '<p>'. SoftgenHelper::kses_basic( SoftgenHelper::get_the_excerpt() ) .'</p>';
					}
				?>
			</div>
		</div>
	</div>
	<?php
		if( 'show' === softgen_get_option( 'ph_lines', 'show' ) ) {
			echo '<div class="lines"><div class="line"></div><div class="line"></div><div class="line"></div><div class="line"></div></div>';
		}
		if( 'show' === softgen_get_option( 'ph_animated_dots', 'show' ) ) {
			echo '<div class="animated-dots">
				<span class="dot lf-left-right"></span>
				<span class="dot lf-up-down"></span>
				<span class="dot lf-up-down"></span>
				<span class="dot lf-rotate-center"></span>
				<span class="dot lf-left-right"></span>
				<span class="dot lf-rotate-center"></span>
			</div>';
		}
    ?>
</section><!-- ./service-header-area -->
<?php if( ! empty( $softgen_project_info ) ) : 
	$softgen_total_p_info = new ArrayObject($softgen_project_info);
?>
<section class="project-info">
	<div class="<?php SoftgenHelper::theme_layout(); ?>">
		<ul class="project-info-list" style="--softgen-project-info-col: <?php echo esc_attr( $softgen_total_p_info->count() ); ?>">
			<?php foreach( $softgen_project_info as $softgen_index => $softgen_info ) : ?>
				<li class="project-info-item">
					<?php
					if( ! empty( $softgen_info['label'] ) ) {
						echo '<h3>'. esc_html( $softgen_info['label'] ) .'</h3>';
					}
					if( 'text' === $softgen_info['type'] ) {
						if( ! empty( $softgen_info['value'] ) ) {
							echo '<p>'. esc_html( $softgen_info['value'] ) .'</p>';
						}
					}elseif( 'date' === $softgen_info['type'] ) {
						if( ! empty( $softgen_info['pick_date'] ) ) {
							echo '<p>'. esc_html( $softgen_info['pick_date'] ) .'</p>';
						}
					}else{
						if( ! empty( $softgen_info['button_label'] && $softgen_info['link'] ) ) {
							echo '<a href="'. esc_url( $softgen_info['link'] ) .'" target="_blank" class="default-btn">'. esc_html( $softgen_info['button_label'] ) .'</a>';
						}
					}
					?>
					<p></p>
				</li>
			<?php endforeach; ?>
		</ul>
	</div>
</section>
<?php endif; ?>
<section class="wrapper">
	<div class="project-container">
		<main id="primary" class="site-main">
			<div id="post-<?php the_ID(); ?>" <?php post_class( array( 'project-content' ) ); ?>>
			<?php
			while ( have_posts() ) : ?>
				<?php
					if( has_post_thumbnail() ) {
						echo '<div class="project-banner-image">';
							the_post_thumbnail('full', ['class' => 'project-single-img'] );
						echo '</div>';
					} 
				?>
				<div class="content-area">
					<?php 
						the_post();
						the_content();
					?>
				</div>
				<?php if( 'show' === softgen_get_option('project_navigation', 'show') ) : ?>
				<div class="project-footer">
					<?php softgen_post_nav(); ?>
				</div>
				<?php 
				endif;
				endwhile; ?>
			</div>
		</main><!-- #main -->
	</div><!-- .container -->
</section>
<?php 
if( 'show' === softgen_get_option( 'related_project', 'hide' ) ) {
	SoftgenRelatedItems::project();
}
if( 'show' === softgen_get_option( 'project_comments', 'hide' ) ) : ?>
<section class="project-comments">
	<div class="container">
		<?php
		if ( comments_open() || get_comments_number() ) {
			comments_template();
		}
		?>
	</div>
</section>
<?php endif; ?>
<?php
get_footer();
